==> chromium-browser-28.0.1500.45.tar.xz: chromium-browser-28.0.1500.45/v8/src/sweeper-thread.h <==
// Copyright 2012 the V8 project authors. All rights reserved.
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
//     * Neither the name of Google Inc. nor the names of its
//       contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef V8_SWEEPER_THREAD_H_
#define V8_SWEEPER_THREAD_H_

#include "atomicops.h"
#include "flags.h"
#include "platform.h"
#include "v8utils.h"

#include "spaces.h"

#include "heap.h"

namespace v8 {
namespace internal {

class SweeperThread : public Thread {
 public:
  explicit SweeperThread(Isolate* isolate);

  void Run();
  void Stop();
  void StartSweeping();
  void WaitForSweeperThread();
  intptr_t StealMemory(PagedSpace* space);

  ~SweeperThread() {
    delete start_sweeping_semaphore_;
    delete end_sweeping_semaphore_;
    delete stop_semaphore_;
  }

 private:
  Isolate* isolate_;
  Heap* heap_;
  MarkCompactCollector* collector_;
  Semaphore* start_sweeping_semaphore_;
  Semaphore* end_sweeping_semaphore_;
  Semaphore* stop_semaphore_;
  FreeList free_list_old_data_space_;
  FreeList free_list_old_pointer_space_;
  FreeList private_free_list_old_data_space_;
  FreeList private_free_list_old_pointer_space_;
  volatile AtomicWord stop_thread_;
};

} }  // namespace v8::internal

#endif  // V8_SWEEPER_THREAD_H_

==> chromium-browser-31.0.1650.57.tar.xz: chromium-browser-31.0.1650.57/v8/src/sweeper-thread.h <==
// Copyright 2012 the V8 project authors. All rights reserved.
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
//     * Neither the name of Google Inc. nor the names of its
//       contributors may be used to endorse or promote products derived
//       from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#ifndef V8_SWEEPER_THREAD_H_
#define V8_SWEEPER_THREAD_H_

#include "atomicops.h"
#include "flags.h"
#include "platform.h"
#include "v8utils.h"

#include "spaces.h"

#include "heap.h"

namespace v8 {
namespace internal {

class SweeperThread : public Thread {
 public:
  explicit SweeperThread(Isolate* isolate);
  ~SweeperThread() {}

  void Run();
  void Stop();
  void StartSweeping();
  void WaitForSweeperThread();
  intptr_t StealMemory(PagedSpace* space);

 private:
  Isolate* isolate_;
  Heap* heap_;
  MarkCompactCollector* collector_;
  Semaphore start_sweeping_semaphore_;
  Semaphore end_sweeping_semaphore_;
  Semaphore stop_semaphore_;
  FreeList free_list_old_data_space_;
  FreeList free_list_old_pointer_space_;
  FreeList private_free_list_old_data_space_;
  FreeList private_free_list_old_pointer_space_;
  volatile AtomicWord stop_thread_;
};

} }  // namespace v8::internal

#endif  // V8_SWEEPER_THREAD_H_
